==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/zh_TW.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "接下來的工作",
    "Important" : "重要",
    "Today" : "今天",
    "Week" : "週",
    "All" : "所有",
    "Current" : "目前",
    "Completed" : "完成",
    "Tasks" : "工作項目",
    "The Tasks app for Nextcloud" : "Nextcloud 的工作項目應用程式",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "一經啟用，新的「工作項目」選單將會出現在您 Nextcloud 應用程式選單中。在此，您可以新增與刪除工作項目、編輯它們的標題、描述、開始與結束日期、標記它們的重要程度。工作項目可在使用者間分享。工作項目可使用 CalDav 同步（每個工作項目列表都會連結到一個 Nextcloud 日曆，用來與您的本機客戶端同步，如 Thunderbird、Evolution、KDE Kontact、iCal 等，只要在您的客戶端中以遠端日曆的形式新增日曆即可）。您可以 ICS 檔案的形式下載您的工作項目，只要按下每個日曆的下載按鈕就好。",
    "Default list" : "預設列表",
    "Visibility of Smart Collections" : "智慧型收藏的能見度",
    "Hidden" : "隱藏",
    "Visible" : "顯示",
    "Automatic" : "自動",
    "Tasks settings" : "工作項目設定",
    "Share with users or groups" : "與使用者或群組分享",
    "No users or groups" : "沒有使用者或群組",
    "Can edit" : "可以編輯",
    "Unshare with {displayName}" : "取消與 {displayName} 的分享",
    "Unable to delete the share." : "無法刪除共享.",
    "Unable to change permissions." : "無法變更權限。",
    "Edit" : "編輯",
    "Copy private link" : "複製私人連結",
    "Copied" : "已複製",
    "Cannot copy" : "無法複製",
    "Export" : "匯出",
    "Delete" : "刪除",
    "Unshare" : "撤回分享",
    "Save" : "儲存",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "這將會刪除日曆「{calendar}」與所有對應的活動與工作項目。",
    "This will unshare the calendar \"{calendar}\"." : "這將會取消共享日曆「{calendar}」。",
    "This will delete the list \"{list}\" and all corresponding tasks." : "這將會刪除列表「{list}」與所有對應的工作項目。",
    "This will unshare the list \"{list}\"." : "這將會取消共享列表「{list}」。",
    "Share this calendar" : "分享此行事曆",
    "Share this list" : "分享此清單",
    "Calendar link copied to clipboard." : "複製日曆連結到剪貼簿",
    "List link copied to clipboard." : "列表連結已複製到剪貼簿。",
    "Calendar link could not be copied to clipboard." : "不能複製日曆連結到剪貼簿",
    "List link could not be copied to clipboard." : "連結無法複製到剪貼簿。",
    "The name \"{calendar}\" is already used." : "名稱「{calendar}」已被使用。",
    "An empty name is not allowed." : "不允許空白的名稱.",
    "An error occurred, unable to delete the calendar." : "遇到錯誤，無法刪除日曆。",
    "An error occurred, unable to delete the list." : "遇到錯誤，無法刪除列表。",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後刪除日曆"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享日曆"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["將在 {countdown} 秒後刪除列表"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享列表"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
    "Trash bin" : "回收桶",
    "Loading deleted calendars, tasks and events." : "正在載入已刪除的日曆、工作項目與活動。",
    "You do not have any deleted calendars, tasks or events." : "您沒有任何已刪除的日曆、工作項目或活動。",
    "Name" : "名稱",
    "Deleted" : "已刪除",
    "Restore" : "還原",
    "Delete permanently" : "永久刪除",
    "Empty trash bin" : "清空回收桶",
    "Untitled task" : "未命名工作項目",
    "Untitled event" : "未命名活動",
    "Untitled journal" : "未命名日誌",
    "Untitled item" : "未命名的項目",
    "Unknown calendar" : "未知行事曆",
    "Could not load deleted calendars and objects" : "無法載入已刪除的日曆與物件",
    "Could not delete calendar or event" : "無法刪除日曆或活動",
    "Could not restore calendar or event" : "無法還原日曆或活動",
    "Do you really want to empty the trash bin?" : "您真的想要清空回收桶嗎？",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["回收桶中的元素將於{numDays}天後刪除"],
    "Select a calendar" : "選取行事曆",
    "No calendar matches the search." : "沒有與搜尋相符的日曆。",
    "Set date" : "設定日期",
    "Set time" : "設定時間",
    "Delete date" : "刪除日期",
    "Click here to add a note." : "點擊此處以新增註解。",
    "Set value" : "設定值",
    "Delete value" : "刪除值",
    "Add this as a new tag" : "將這個新增為新標籤",
    "No tag available. Create one!" : "沒有可用的標籤。建立一個！",
    "Delete all completed tasks." : "刪除所有已完成的工作項目。",
    "Delete completed tasks." : "刪除已完成的工作項目。",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "從日曆「{calendar}」刪除了所有已完成的工作項目。",
    "No errors" : "沒有錯誤",
    "Open your browser console for more details" : "開啟您的瀏覽器主控台以取得詳細資訊",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["這將會從日曆「{calendar}」刪除 {taskCount} 個已完成的工作項目與其子項目。"],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["無法刪除 {failedCount} 個工作項目。"],
    "Add an important task to \"{calendar}\"…" : "新增重要工作項目到「{calendar}」……",
    "Add a task due today to \"{calendar}\"…" : "新增今天到期的工作項目到「{calendar}」……",
    "Add a current task to \"{calendar}\"…" : "新增目前的工作項目到「{calendar}」……",
    "Add a task to \"{calendar}\"…" : "新增工作項目到「{calendar}」……",
    "Load all completed tasks." : "載入所有已完成的工作項目。",
    "Change sort order" : "改變分類順序",
    "Relevance" : "關聯",
    "Sort by completed state, due date, priority, start date and summary." : "按完成狀態、結束日期、優先程度、開始日期與摘要排序。",
    "Start date" : "開始日期",
    "Sort by start date and summary." : "按開始日期與摘要排序。",
    "Due date" : "到期日",
    "Sort by due date and summary." : "按截止日期與摘要排序。",
    "Created date" : "建立日期",
    "Sort by created date and summary." : "按建立日期與摘要排序。",
    "Last modified" : "上一次修改",
    "Sort by last-modified date and summary." : "按最後修改日期與摘要排序。",
    "Completed date" : "完成日期",
    "Sort by completed date." : "按完成日期排序。",
    "Priority" : "優先",
    "Sort by priority and summary." : "按優先程度與摘要排序。",
    "Alphabetically" : "字母",
    "Sort by summary and priority." : "按摘要與優先程度排序。",
    "Manually" : "手動",
    "Sort by manual order." : "手動排序。",
    "{complete} % completed" : "{complete} % 完成",
    "Task has hidden subtasks" : "工作項目有隱藏的子工作項目",
    "Task has not yet started" : "工作項目尚未開始",
    "Task is pinned" : "工作項目已釘選",
    "Task has a note" : "工作項目有註記",
    "Add subtask" : "新增子工作項目",
    "Show subtasks" : "顯示子工作項目",
    "Hide subtasks" : "隱藏子工作項目",
    "Show closed subtasks" : "顯示已關閉的子工作項目",
    "Hide closed subtasks" : "隱藏已關閉的子工作項目",
    "Delete task" : "刪除工作項目",
    "Toggle starred" : "加上／移除星號",
    "[Yesterday]" : "[昨天]",
    "[Today]" : "[今天]",
    "[Tomorrow]" : "[明天]",
    "[Completed yesterday]" : "[昨天完成]",
    "[Completed today]" : "[今天完成]",
    "[Completed tomorrow]" : "[明天完成]",
    "[Yesterday at] LT" : "[昨天於] LT",
    "[Today at] LT" : "[今天於] LT",
    "[Tomorrow at] LT" : "[明天於] LT",
    "L [at] LT" : "L [於] LT",
    "[Completed yesterday at] LT" : "[昨天完成於] LT",
    "[Completed today at] LT" : "[今天完成於] LT",
    "[Completed tomorrow at] LT" : "[明天完成於] LT",
    "[Completed] L [at] LT" : "[完成] L [於] LT",
    "Add a subtask to \"{task}\"…" : "新增子工作項目到「{task}」……",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["將在 {countdown} 秒後刪除工作項目"],
    "Task is cancelled" : "工作項目已被取消",
    "Task is completed" : "工作項目已完成",
    "Task is read-only" : "工作項目唯讀",
    "Task is not completed" : "工作項目未完成",
    "Create a new task" : "建立新工作項目",
    "Task summary" : "工作項目摘要",
    "Cancel" : "取消",
    "Create task" : "建立工作項目",
    "Creating the new task…" : "正在建立新工作項目",
    "\"{task}\" was added to \"{calendar}\"" : "「{task}」已被新增至「{calendar}」",
    "Close" : "關閉",
    "Open task" : "開啟工作項目",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n 完成任務"],
    "Tomorrow" : "明天",
    "Add List…" : "增加清單...",
    "New List" : "新列表",
    "All day" : "全天",
    "Unpin" : "取消釘選",
    "Pin" : "釘選",
    "Show in Calendar" : "在日曆中顯示",
    "Edit title" : "編輯標題",
    "Details" : "詳細資料",
    "Select a classification" : "選取分類",
    "Select a status" : "選取狀態",
    "Select tags" : "選取標籤",
    "Notes" : "註解",
    "Reminders" : "提醒",
    "Repeat" : "重複",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared show only busy" : "分享的時候顯示忙碌中",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "[Completed] L" : "[完成] L",
    "[Completed last] dddd [at] LT" : "[最後完成] dddd [於] LT",
    "[Completed] dddd [at] LT" : "[完成] dddd [於] LT",
    "[Last modified yesterday at] LT" : "[上次修改時間：昨天] LT",
    "[Last modified today at] LT" : "[上次修改時間：今天] LT",
    "[Last modified] L" : "[最後修改] L",
    "[Last modified last] dddd [at] LT" : "[最後修改時間] dddd [於] LT",
    "[Last modified] dddd [at] LT" : "[最後修改] dddd [於] LT",
    "[Created yesterday at] LT" : "[昨天建立於] LT",
    "[Created today at] LT" : "[今天建立於] LT",
    "[Created] L" : "[建立] L",
    "[Created last] dddd [at] LT" : "[最後建立] dddd [於] LT",
    "[Created] dddd [at] LT" : "[建立] dddd [於] LT",
    "Needs action" : "需要動作",
    "In process" : "進行中",
    "Canceled" : "已取消",
    "Clear status" : "清除狀態",
    "Loading task from server." : "正在從伺服器載入工作項目。",
    "Task not found!" : "找不到任務!",
    "[Starts today]" : "[今天開始]",
    "[Starts tomorrow]" : "[昨天開始]",
    "[Starts on] LL" : "[開始於] LL",
    "[Started yesterday]" : "[昨天開始]",
    "[Started on] LL" : "[開始於] LL",
    "[Started today at] LT" : "[今天開始於] LT",
    "[Starts today at] LT" : "[今天開始於] LT",
    "[Starts tomorrow at] LT" : "[明天開始於] LT",
    "[Starts on] LL [at] LT" : "[開始在] LL [於] LT",
    "[Started yesterday at] LT" : "[昨天開始於] LT",
    "[Started on] LL [at] LT" : "[開始在] LL [於] LT",
    "Set start date" : "指定開始日期",
    "[Due today]" : "[今天到期]",
    "[Due tomorrow]" : "[明天到期]",
    "[Due on] LL" : "[到期於] LL",
    "[Was due yesterday]" : "[昨天到期]",
    "[Was due on] LL" : "[到期於] LL",
    "[Was due today at] LT" : "[今天到期於] LT",
    "[Due today at] LT" : "[今天到期於] LT",
    "[Due tomorrow at] LT" : "[明天到期於] LT",
    "[Due on] LL [at] LT" : "[到期在] LL [於] LT",
    "[Was due yesterday at] LT" : "[昨天到期於] LT",
    "[Was due on] LL [at] LT" : "[到期在] LL [於] LT",
    "Set due date" : "指定到期日",
    "Priority {priority}: low" : "優先程度 {priority}：低",
    "Priority {priority}: medium" : "優先程度 {priority}：中",
    "Priority {priority}: high" : "優先程度 {priority}：高",
    "No priority assigned" : "未指定優先程度",
    "{percent} % completed" : "{percent} % 完成",
    "No upcoming tasks" : "沒有接下來的工作",
    "upcoming tasks" : "接下來的工作",
    "No tasks today" : "今日無工作",
    "Mark as done" : "標記為完成",
    "No due date assigned" : "未指定到期日",
    "[Due yesterday]" : "[昨天截止]",
    "[Due] L" : "[截止於] L",
    "[Due yesterday at] LT" : "[昨天截止於] LT",
    "[Due] L [at] LT" : "[截止] L [於] LT",
    "Successfully created the task." : "成功建立工作項目。",
    "Could not delete the task." : "無法刪除工作項目。",
    "Synchronizing to the server." : "與伺服器同步。",
    "Task successfully saved to server." : "工作項目已成功儲存到伺服器。",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "無法更新工作項目，因為其在伺服器上已變更。請點擊以重新整理，本機變更將會被丟棄。",
    "Could not update the task." : "無法更新工作項目。",
    "Successfully updated the task." : "成功更新工作項目。",
    "Task successfully moved to new calendar." : "工作項目成功移動到新的日曆。",
    "An error occurred" : "發生錯誤",
    "Create a task" : "建立工作項目",
    "Message from {author} in {conversationName}" : "來自 {conversationName} 中 {author} 的訊息"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/zh_TW.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "接下來的工作",
    "Important" : "重要",
    "Today" : "今天",
    "Week" : "週",
    "All" : "所有",
    "Current" : "目前",
    "Completed" : "完成",
    "Tasks" : "工作項目",
    "The Tasks app for Nextcloud" : "Nextcloud 的工作項目應用程式",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "一經啟用，新的「工作項目」選單將會出現在您 Nextcloud 應用程式選單中。在此，您可以新增與刪除工作項目、編輯它們的標題、描述、開始與結束日期、標記它們的重要程度。工作項目可在使用者間分享。工作項目可使用 CalDav 同步（每個工作項目列表都會連結到一個 Nextcloud 日曆，用來與您的本機客戶端同步，如 Thunderbird、Evolution、KDE Kontact、iCal 等，只要在您的客戶端中以遠端日曆的形式新增日曆即可）。您可以 ICS 檔案的形式下載您的工作項目，只要按下每個日曆的下載按鈕就好。",
    "Default list" : "預設列表",
    "Visibility of Smart Collections" : "智慧型收藏的能見度",
    "Hidden" : "隱藏",
    "Visible" : "顯示",
    "Automatic" : "自動",
    "Tasks settings" : "工作項目設定",
    "Share with users or groups" : "與使用者或群組分享",
    "No users or groups" : "沒有使用者或群組",
    "Can edit" : "可以編輯",
    "Unshare with {displayName}" : "取消與 {displayName} 的分享",
    "Unable to delete the share." : "無法刪除共享.",
    "Unable to change permissions." : "無法變更權限。",
    "Edit" : "編輯",
    "Copy private link" : "複製私人連結",
    "Copied" : "已複製",
    "Cannot copy" : "無法複製",
    "Export" : "匯出",
    "Delete" : "刪除",
    "Unshare" : "撤回分享",
    "List name" : "列表名稱",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "這將會刪除日曆「{calendar}」與所有對應的活動與工作項目。",
    "This will unshare the calendar \"{calendar}\"." : "這將會取消共享日曆「{calendar}」。",
    "This will delete the list \"{list}\" and all corresponding tasks." : "這將會刪除列表「{list}」與所有對應的工作項目。",
    "This will unshare the list \"{list}\"." : "這將會取消共享列表「{list}」。",
    "Share this calendar" : "分享此行事曆",
    "Share this list" : "分享此清單",
    "Calendar link copied to clipboard." : "複製日曆連結到剪貼簿",
    "List link copied to clipboard." : "列表連結已複製到剪貼簿。",
    "Calendar link could not be copied to clipboard." : "不能複製日曆連結到剪貼簿",
    "List link could not be copied to clipboard." : "連結無法複製到剪貼簿。",
    "The name \"{calendar}\" is already used." : "名稱「{calendar}」已被使用。",
    "An empty name is not allowed." : "不允許空白的名稱.",
    "An error occurred, unable to delete the calendar." : "遇到錯誤，無法刪除日曆。",
    "An error occurred, unable to delete the list." : "遇到錯誤，無法刪除列表。",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後刪除日曆"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享日曆"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["將在 {countdown} 秒後刪除列表"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享列表"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
    "Trash bin" : "回收桶",
    "Loading deleted calendars, tasks and events." : "正在載入已刪除的日曆、工作項目與活動。",
    "You do not have any deleted calendars, tasks or events." : "您沒有任何已刪除的日曆、工作項目或活動。",
    "Name" : "名稱",
    "Deleted" : "已刪除",
    "Restore" : "還原",
    "Delete permanently" : "永久刪除",
    "Empty trash bin" : "清空回收桶",
    "Untitled task" : "未命名工作項目",
    "Untitled event" : "未命名活動",
    "Untitled journal" : "未命名日誌",
    "Untitled item" : "未命名的項目",
    "Unknown calendar" : "未知行事曆",
    "Could not load deleted calendars and objects" : "無法載入已刪除的日曆與物件",
    "Could not delete calendar or event" : "無法刪除日曆或活動",
    "Could not restore calendar or event" : "無法還原日曆或活動",
    "Do you really want to empty the trash bin?" : "您真的想要清空回收桶嗎？",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["回收桶中的元素將於{numDays}天後刪除"],
    "Select a calendar" : "選取行事曆",
    "No calendar matches the search." : "沒有與搜尋相符的日曆。",
    "Set date" : "設定日期",
    "Set time" : "設定時間",
    "Delete date" : "刪除日期",
    "Click here to add a note." : "點擊此處以新增註解。",
    "Set value" : "設定值",
    "Delete value" : "刪除值",
    "Add this as a new tag" : "將這個新增為新標籤",
    "No tag available. Create one!" : "沒有可用的標籤。建立一個！",
    "Delete all completed tasks." : "刪除所有已完成的工作項目。",
    "Delete completed tasks." : "刪除已完成的工作項目。",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "從日曆「{calendar}」刪除了所有已完成的工作項目。",
    "No errors" : "沒有錯誤",
    "Open your browser console for more details" : "開啟您的瀏覽器主控台以取得詳細資訊",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["這將會從日曆「{calendar}」刪除 {taskCount} 個已完成的工作項目與其子項目。"],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["無法刪除 {failedCount} 個工作項目。"],
    "Add an important task to \"{calendar}\"…" : "新增重要工作項目到「{calendar}」……",
    "Add a task due today to \"{calendar}\"…" : "新增今天到期的工作項目到「{calendar}」……",
    "Add a current task to \"{calendar}\"…" : "新增目前的工作項目到「{calendar}」……",
    "Add a task to \"{calendar}\"…" : "新增工作項目到「{calendar}」……",
    "Load the completed tasks of all lists." : "載入所有清單的已完成工作。",
    "Loading the completed tasks of all lists might slow down the app." : "載入所有清單的已完成工作可能會拖慢應用程式的速度。",
    "Load the completed tasks of list \"{calendar}\"." : "載入「{calendar}」清單的已完成工作。",
    "Change sort order" : "改變分類順序",
    "Relevance" : "關聯",
    "Sort by completed state, due date, priority, start date and summary." : "按完成狀態、結束日期、優先程度、開始日期與摘要排序。",
    "Start date" : "開始日期",
    "Sort by start date, priority and summary." : "按開始日期、優先程度與摘要排序。",
    "Due date" : "到期日",
    "Sort by due date, priority and summary." : "按截止日期、優先程度與摘要排序。",
    "Created date" : "建立日期",
    "Sort by created date, priority and summary." : "按建立日期、優先程度與摘要排序。",
    "Last modified" : "上一次修改",
    "Sort by last-modified date, priority and summary." : "按最後修改日期、優先程度與摘要排序。",
    "Completed date" : "完成日期",
    "Sort by completed date, priority and summary." : "按完成日期、優先程度與摘要排序。",
    "Priority" : "優先",
    "Sort by priority and summary." : "按優先程度與摘要排序。",
    "Alphabetically" : "字母",
    "Sort by summary and priority." : "按摘要與優先程度排序。",
    "Manually" : "手動",
    "Sort by manual order." : "手動排序。",
    "{complete} % completed" : "{complete} % 完成",
    "Task has hidden subtasks" : "工作項目有隱藏的子工作項目",
    "Task has not yet started" : "工作項目尚未開始",
    "Task is pinned" : "工作項目已釘選",
    "Task has a note" : "工作項目有註記",
    "Add subtask" : "新增子工作項目",
    "Show subtasks" : "顯示子工作項目",
    "Hide subtasks" : "隱藏子工作項目",
    "Show closed subtasks" : "顯示已關閉的子工作項目",
    "Hide closed subtasks" : "隱藏已關閉的子工作項目",
    "Delete task" : "刪除工作項目",
    "Toggle starred" : "加上／移除星號",
    "[Yesterday]" : "[昨天]",
    "[Today]" : "[今天]",
    "[Tomorrow]" : "[明天]",
    "[Completed yesterday]" : "[昨天完成]",
    "[Completed today]" : "[今天完成]",
    "[Completed tomorrow]" : "[明天完成]",
    "[Yesterday at] LT" : "[昨天於] LT",
    "[Today at] LT" : "[今天於] LT",
    "[Tomorrow at] LT" : "[明天於] LT",
    "L [at] LT" : "L [於] LT",
    "[Completed yesterday at] LT" : "[昨天完成於] LT",
    "[Completed today at] LT" : "[今天完成於] LT",
    "[Completed tomorrow at] LT" : "[明天完成於] LT",
    "[Completed] L [at] LT" : "[完成] L [於] LT",
    "Add a subtask to \"{task}\"…" : "新增子工作項目到「{task}」……",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["將在 {countdown} 秒後刪除工作項目"],
    "Task is cancelled" : "工作項目已被取消",
    "Task is completed" : "工作項目已完成",
    "Task is read-only" : "工作項目唯讀",
    "Task is not completed" : "工作項目未完成",
    "Create a new task" : "建立新工作項目",
    "Task summary" : "工作項目摘要",
    "Cancel" : "取消",
    "Create task" : "建立工作項目",
    "Creating the new task…" : "正在建立新工作項目",
    "Close" : "關閉",
    "Open task" : "開啟工作項目",
    "\"{task}\" was added to \"{calendar}\"" : "「{task}」已被新增至「{calendar}」",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n 完成任務"],
    "Tomorrow" : "明天",
    "Add List…" : "增加清單...",
    "New list" : "新清單",
    "All day" : "全天",
    "Unpin" : "取消釘選",
    "Pin" : "釘選",
    "Show in Calendar" : "在日曆中顯示",
    "Edit title" : "編輯標題",
    "Details" : "詳細資料",
    "Selecting a classification is forbidden, because the task was shared with you." : "因為工作已與您分享，因此您無法選取分類。",
    "Select a classification" : "選取分類",
    "Select a status" : "選取狀態",
    "Select tags" : "選取標籤",
    "Notes" : "註解",
    "Reminders" : "提醒",
    "Repeat" : "重複",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared show only busy" : "分享的時候顯示忙碌中",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "[Completed] L" : "[完成] L",
    "[Completed last] dddd [at] LT" : "[最後完成] dddd [於] LT",
    "[Completed] dddd [at] LT" : "[完成] dddd [於] LT",
    "[Last modified yesterday at] LT" : "[上次修改時間：昨天] LT",
    "[Last modified today at] LT" : "[上次修改時間：今天] LT",
    "[Last modified] L" : "[最後修改] L",
    "[Last modified last] dddd [at] LT" : "[最後修改時間] dddd [於] LT",
    "[Last modified] dddd [at] LT" : "[最後修改] dddd [於] LT",
    "[Created yesterday at] LT" : "[昨天建立於] LT",
    "[Created today at] LT" : "[今天建立於] LT",
    "[Created] L" : "[建立] L",
    "[Created last] dddd [at] LT" : "[最後建立] dddd [於] LT",
    "[Created] dddd [at] LT" : "[建立] dddd [於] LT",
    "Needs action" : "需要動作",
    "In process" : "進行中",
    "Canceled" : "已取消",
    "Clear status" : "清除狀態",
    "Loading task from server." : "正在從伺服器載入工作項目。",
    "Task not found!" : "找不到任務!",
    "[Starts today]" : "[今天開始]",
    "[Starts tomorrow]" : "[昨天開始]",
    "[Starts on] LL" : "[開始於] LL",
    "[Started yesterday]" : "[昨天開始]",
    "[Started on] LL" : "[開始於] LL",
    "[Started today at] LT" : "[今天開始於] LT",
    "[Starts today at] LT" : "[今天開始於] LT",
    "[Starts tomorrow at] LT" : "[明天開始於] LT",
    "[Starts on] LL [at] LT" : "[開始在] LL [於] LT",
    "[Started yesterday at] LT" : "[昨天開始於] LT",
    "[Started on] LL [at] LT" : "[開始在] LL [於] LT",
    "Set start date" : "指定開始日期",
    "[Due today]" : "[今天到期]",
    "[Due tomorrow]" : "[明天到期]",
    "[Due on] LL" : "[到期於] LL",
    "[Was due yesterday]" : "[昨天到期]",
    "[Was due on] LL" : "[到期於] LL",
    "[Was due today at] LT" : "[今天到期於] LT",
    "[Due today at] LT" : "[今天到期於] LT",
    "[Due tomorrow at] LT" : "[明天到期於] LT",
    "[Due on] LL [at] LT" : "[到期在] LL [於] LT",
    "[Was due yesterday at] LT" : "[昨天到期於] LT",
    "[Was due on] LL [at] LT" : "[到期在] LL [於] LT",
    "Set due date" : "指定到期日",
    "Priority {priority}: low" : "優先程度 {priority}：低",
    "Priority {priority}: medium" : "優先程度 {priority}：中",
    "Priority {priority}: high" : "優先程度 {priority}：高",
    "No priority assigned" : "未指定優先程度",
    "{percent} % completed" : "{percent} % 完成",
    "No upcoming tasks" : "沒有接下來的工作",
    "upcoming tasks" : "接下來的工作",
    "No tasks today" : "今日無工作",
    "Mark as done" : "標記為完成",
    "No due date assigned" : "未指定到期日",
    "[Due yesterday]" : "[昨天截止]",
    "[Due] L" : "[截止於] L",
    "[Due yesterday at] LT" : "[昨天截止於] LT",
    "[Due] L [at] LT" : "[截止] L [於] LT",
    "Successfully created the task." : "成功建立工作項目。",
    "Could not delete the task." : "無法刪除工作項目。",
    "Synchronizing to the server." : "與伺服器同步。",
    "Task successfully saved to server." : "工作項目已成功儲存到伺服器。",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "無法更新工作項目，因為其在伺服器上已變更。請點擊以重新整理，本機變更將會被丟棄。",
    "Could not update the task." : "無法更新工作項目。",
    "Successfully updated the task." : "成功更新工作項目。",
    "Task successfully moved to new calendar." : "工作項目成功移動到新的日曆。",
    "An error occurred" : "發生錯誤",
    "Create a task" : "建立工作項目",
    "Message from {author} in {conversationName}" : "來自 {conversationName} 中 {author} 的訊息"
},
"nplurals=1; plural=0;");
